/*
 *	File selection menu
 *	Copyright
 *		(C) 1992 Joseph H. Allen
 *
 *	This file is part of JOE (Joe's Own Editor)
 */
#ifndef _JOE_TAB_H
#define _JOE_TAB_H 1

#ifdef EXTERN_UFILE_C
__IDSTRING(rcsid_tab_h, "$MirOS: contrib/code/jupp/tab.h,v 1.5 2017/12/06 21:17:00 tg Exp $");
#endif

int cmplt(BW *bw);

#endif
